%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% World Trade Model with Transport
% by Anders Stromman and Faye Duchin
%
% Programmed by
% Kristin Fjellheim
% October 21 2010
%
% This Matlab file use the results obtained from the running by GAMS and
% statistical data from GTAP to form the desired results
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Output

% Output by sector summed over all countries
x_stat_sec = sum(g,2);
x_mod_sec = sum(x_bot_z_z,2);
x_nt_sec = sum(x_nt,2);

x_stat_15sec = Sec15' * x_stat_sec;
x_mod_15sec = Sec15' * x_mod_sec;
x_nt_15sec = Sec15' * x_nt_sec;

% Output by country summed over all products
x_stat_reg = sum(g,1)';
x_mod_reg = sum(x_bot_z_z,1)';
x_nt_reg = sum(x_nt,1)';

x_stat_11reg = RelCR_11' * x_stat_reg;
x_mod_11reg = RelCR_11' * x_mod_reg;
x_nt_11reg = RelCR_11' * x_nt_reg;

x_stat_6reg = RelCR_6' * x_stat_11reg;
x_mod_6reg = RelCR_6' * x_mod_11reg;
x_nt_6reg = RelCR_6' * x_nt_11reg;

% Output flows
x_stat_flow = Sec15' * g;
x_mod_flow = Sec15' * x_bot_z_z;
x_nt_flow = Sec15' * x_nt;

x_stat_flow_11Reg = x_stat_flow * RelCR_11;
x_mod_flow_11Reg = x_mod_flow * RelCR_11;
x_nt_flow_11Reg = x_nt_flow * RelCR_11;

x_stat_flow_6Reg = x_stat_flow_11Reg * RelCR_6;
x_mod_flow_6Reg = x_mod_flow_11Reg * RelCR_6;
x_nt_flow_6Reg = x_nt_flow_11Reg * RelCR_6;
%% Endowments

% Endowment per country
for r = 1:i_max
    E_stat(:,r) = F(:,:,r) * g(:,r);
end
for r = 1:i_max
     E_mod(:,r) = F(:,:,r) * x_bot_z_z(:,r);
end
for r = 1:i_max
    E_nt(:,r) = F(:,:,r) * x_nt(:,r);
end

E_stat_11reg = E_stat * RelCR_11;
E_mod_11reg = E_mod * RelCR_11;
E_nt_11reg = E_nt * RelCR_11;

E_stat_6reg = E_stat_11reg * RelCR_6;
E_mod_6reg = E_mod_11reg * RelCR_6;
E_nt_6reg = E_nt_11reg * RelCR_6;

E_stat_sum = sum(E_stat,1)';
E_mod_sum = sum(E_mod,1)';
E_nt_sum = sum(E_nt,1)';
E_stat_sum11 = sum(E_stat_11reg)';
E_mod_sum11 = sum(E_mod_11reg)';
E_nt_sum11 = sum(E_nt_11reg)';
E_stat_sum6 = sum(E_stat_6reg)';
E_mod_sum6 = sum(E_mod_6reg)';
E_nt_sum6 = sum(E_nt_6reg)';

% Primary factor use per sector
for e = 1:k_max
    for t = 1:n_max
        for r = 1:i_max
            F_stat_sec(e,t,r) = F(e,t,r) * g(t,r);
            F_nt_sec(e,t,r) = F(e,t,r) * x_nt(t,r);
            F_mod_sec(e,t,r) = F(e,t,r) * x_bot_z_z(t,r);
        end
    end
end
F_stat_sec = sum(F_stat_sec,3);
F_nt_sec = sum(F_nt_sec,3);
F_mod_sec = sum(F_mod_sec,3);

F_stat_15sec = F_stat_sec * Sec15;
F_nt_15sec = F_nt_sec * Sec15;
F_mod_15sec = F_mod_sec * Sec15;
%% Exports and Imports

% Exports flows
ex_stat = vxmd;
ex_mod = ex_bot_z_z;

ex_stat_reg = sum(ex_stat,1);
ex_stat_reg = reshape(ex_stat_reg,113,113);
ex_mod_reg = sum(ex_mod,1);
ex_mod_reg = reshape(ex_mod_reg,113,113);

ex_stat_11reg = ex_stat_reg * RelCR_11;
ex_stat_11reg = RelCR_11' * ex_stat_11reg;
ex_mod_11reg = ex_mod_reg * RelCR_11;
ex_mod_11reg = RelCR_11' * ex_mod_11reg;

ex_stat_6reg = ex_stat_11reg * RelCR_6;
ex_stat_6reg = RelCR_6' * ex_stat_6reg;
ex_mod_6reg = ex_mod_11reg * RelCR_6;
ex_mod_6reg = RelCR_6' * ex_mod_6reg;

% Total exports and imports
EX_stat_reg = sum(ex_stat_reg,2);
EX_mod_reg = sum(ex_mod_reg,2);
EX_stat_11reg = RelCR_11' * EX_stat_reg;
EX_mod_11reg = RelCR_11' * EX_mod_reg;
EX_stat_6reg = RelCR_6' * EX_stat_11reg;
EX_mod_6reg = RelCR_6' * EX_mod_11reg;

IM_stat_reg = sum(ex_stat_reg,1)';
IM_mod_reg = sum(ex_mod_reg,1)';
IM_stat_11reg = RelCR_11' * IM_stat_reg;
IM_mod_11reg = RelCR_11' * IM_mod_reg;
IM_stat_6reg = RelCR_6' * IM_stat_11reg;
IM_mod_6reg = RelCR_6' * IM_mod_11reg;

EX_stat_prodsh = EX_stat_reg ./ x_stat_reg;
EX_mod_prodsh = EX_mod_reg ./ x_mod_reg;
EX_stat_prodsh11 = EX_stat_11reg ./ x_stat_11reg;
EX_mod_prodsh11 = EX_mod_11reg ./ x_mod_11reg;
EX_stat_prodsh6 = EX_stat_6reg ./ x_stat_6reg;
EX_mod_prodsh6 = EX_mod_6reg ./ x_stat_6reg;

IM_stat_prodsh = IM_stat_reg ./ x_stat_reg;
IM_mod_prodsh = IM_mod_reg ./ x_mod_reg;
IM_stat_prodsh11 = IM_stat_11reg ./ x_stat_11reg;
IM_mod_prodsh11 = IM_mod_11reg ./ x_mod_11reg;
IM_stat_prodsh6 = IM_stat_6reg ./ x_stat_6reg;
IM_mod_prodsh6 = IM_mod_6reg ./ x_mod_6reg;

% Total flows of products
ex_stat_sec = sum(vxmd,3);
ex_stat_sec = sum(ex_stat_sec,2);
ex_mod_sec = sum(ex_bot_z_z,3);
ex_mod_sec = sum(ex_mod_sec,2);

ex_stat_15sec = Sec15' * ex_stat_sec;
ex_mod_15sec = Sec15' * ex_mod_sec;

%% Prices
for r = 1:i_max
    p_nt(:,r)=inv(I-A(:,:,r)')*F(:,:,r)'*PI(:,r);
end

for i = 1:i_max
    pdecA1(:,:,i) = A(:,:,i)' * diag(P_bot_z_z(:,i));
    pdecA2(:,:,i) = -F(:,:,i)' * diag(r_bot_z_z(:,i));
    pdecA3temp(:,:,i) = -(I-A(:,:,i))' * diag(P_nt(:,i)) * alpha_bot_z(i);
    pdecA3(:,i) = sum(pdecA3temp(:,:,i),2);
    pdecA4(:,:,i) = F(:,:,i)' * diag(PI(:,i));
    pdecA0(:,i) = - P_bot_z_z(:,i) + (sum(pdecA1(:,:,i)') + sum(pdecA2(:,:,i)') + sum(pdecA3(:,i)') + sum(pdecA4(:,:,i)'))';
end

%% BOT
for r = 1:i_max
    BOT_stat(:,r) = (I-A(:,:,r)) * g(:,r);
end
BOT_stat_wp = BOT_stat .* P_bot_z_z;
for r = 1:i_max
    BOT_nt(:,r) = (I-A(:,:,r)) * x_nt(:,r);
end
for r = 1:i_max
    BOT_mod(:,r) = (I-A(:,:,r)) * x_bot_z_z(:,r);
end
BOT_mod_wp = BOT_mod .* P_bot_z_z;

BOT_stat_11reg = BOT_stat * RelCR_11;
BOT_mod_11reg = BOT_mod * RelCR_11;

BOT_stat_6reg = BOT_stat_11reg * RelCR_6;
BOT_mod_6reg = BOT_mod_11reg * RelCR_6;

BOT_stat_sum = sum(BOT_stat,1)';
BOT_nt_sum = sum(BOT_nt,1)';
BOT_mod_sum = sum(BOT_mod,1)';
BOT_stat_sum_wp = sum(BOT_stat_wp,1)';
BOT_mod_sum_wp = sum(BOT_mod_wp,1)';

BOT_stat_sum11 = RelCR_11' * BOT_stat_sum;
BOT_mod_sum11 = RelCR_11' * BOT_mod_sum;
BOT_nt_sum11 = RelCR_11' * BOT_nt_sum;
BOT_stat_sum11_wp = RelCR_11' * BOT_stat_sum_wp;
BOT_mod_sum11_wp = RelCR_11' * BOT_mod_sum_wp;

BOT_stat_sum6 = RelCR_6' * BOT_stat_sum11;
BOT_mod_sum6 = RelCR_6' * BOT_mod_sum11;

Y_11reg = Y * RelCR_11;
Y_6reg = Y_11reg * RelCR_6;

Y_sum = sum(Y,1)';
Y_sum11 = RelCR_11' * Y_sum;
Y_sum6 = RelCR_6' * Y_sum11;

BOT_mod_test = BOT_mod .* p_nt;
BOT_stat_test = BOT_stat .* p_nt;
BOT_stat_sum_test = sum(BOT_stat_test,1)';
BOT_mod_sum_test = sum(BOT_mod_test,1)';
Y_test = Y .* p_nt;
Y_sum_test = sum(Y_test,1)';

%%
Y_sec = sum(Y,2);
Y_sec15 = Sec15' * Y_sec;
for t = 1:n_max
    Inter_sec(t,:) = (I-A(:,t,:)) * g(t,:);
end
