********************************************************************************
*
* World Trade Model with Transport
* by Anders Stromman and Faye Duchin
*
*
* Programmed by
* Anders Hammer Stromman
* June 29 2004
*
* This Gams file must be run via Matlab
********************************************************************************

$include set.gms

;

ALIAS(i,j);
ALIAS(j,i);
ALIAS(n, nn);
ALIAS(nn, n);


PARAMETERS

PI(k,i)          regional factor prices

F(k,n,i)         regional factor requirements per unit of output

A(n,nn,i)        regional intermed inputs per unit of output

E(k,i)           regional factor endowments

Y(n,i)           regional commodity demand

T(n,nn,i,j)      requirements of transportation from i to j

P_nt(n,i)        regional no trade prices

ID(n,nn)         identity matrix

IJ(i,j)          parameter for use with gams syntax logical condition

S(n)             environmental stressor matrix

$include matdata.gms

FREE VARIABLES
z         world factor cost

POSITIVE VARIABLES
x(n,i)    regional production
ex(n,i,j) export of good n from i to j


EQUATIONS

world_factor_cost        world total factor cost - objective function
com_balance(n,i)         regional commodity balance
*export_elec(i,j)         no trade
*export_serv(i,j)         no trade
factor_constr(k,i)       regional factor constraint
no_reexport(i,j,n)
bot(i)                   benefit of trade constraint

;

world_factor_cost..      z =e= sum( (i,k,n), PI(k,i)*F(k,n,i)*x(n,i) );

com_balance(n,i)..       x(n,i)
                         - sum( (nn), A(n,nn,i)*x(nn,i) )
                         + sum( (j,nn), (ID(n,nn)-T(n,nn,j,i) )*ex(nn,j,i) )
                         - sum( (j), ex(n,i,j) )
                         =g= Y(n,i);


*export_elec(i,j)..     ex('elec',i,j)=e=0;
*export_serv(i,j)..     ex('serv',i,j)=e=0;


no_reexport(i,j,n)$IJ(i,j)..     ex(n,i,j)=e=0;

factor_constr(k,i)..     sum( (n), F(k,n,i)*x(n,i) ) =l= E(k,i);

bot(i)..                 sum( (n,nn), P_nt(n,i)*(ID(n,nn)-A(n,nn,i))*x(nn,i) )
                         =l= sum( (n), P_nt(n,i)*Y(n,i) );





MODEL WorldTradeModelWithTransport
*/world_factor_cost,com_balance,export_elec,export_serv,no_reexport,factor_constr,bot/;
/world_factor_cost,com_balance,no_reexport,factor_constr/;

WorldTradeModelWithTransport.reslim = 100000;

WorldTradeModelWithTransport.iterlim = 100000000;

SOLVE WorldTradeModelWithTransport USING LP MINIMIZING z

*****************************************************
*   Matlab Output
*****************************************************
*PARAMETER co2         world total carbon emissions - alternative objective function;
*co2 = sum( (i,n), S(n)*x.l(n,i) );

$libinclude matout com_balance.m n i
$libinclude matout z.l
*$libinclude matout co2
$libinclude matout x.l n i
$libinclude matout ex.l n i j
$libinclude matout factor_constr.m k i
*$libinclude matout bot.m i
